pub struct MonetaryAmount {
pub currency: String,
pub amount: f64,
}Expand description
ISO 4217 monetary amount.
Skips serialisation when both fields are empty/zero — keeps the JSON-LD compact when authors leave the amount out of frontmatter.
Fields
currency: StringISO 4217 currency code (e.g. EUR, USD).
amount: f64Numeric amount.
Implementations
Sourceimpl MonetaryAmount
impl MonetaryAmount
Sourcepub fn to_jsonld(&self) -> Value
pub fn to_jsonld(&self) -> Value
Renders to a Schema.org MonetaryAmount JSON value.
Examples
use ssg::seo::jsonld::iso20022::MonetaryAmount;
let m = MonetaryAmount { currency: "EUR".into(), amount: 100.0 };
let v = m.to_jsonld();
assert_eq!(v["currency"], "EUR");
assert_eq!(v["value"], 100.0);Trait Implementations
Sourceimpl Clone for MonetaryAmount
impl Clone for MonetaryAmount
Sourcefn clone(&self) -> MonetaryAmount
fn clone(&self) -> MonetaryAmount
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MonetaryAmount
impl Debug for MonetaryAmount
Sourceimpl<'de> Deserialize<'de> for MonetaryAmount
impl<'de> Deserialize<'de> for MonetaryAmount
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for MonetaryAmount
impl PartialEq for MonetaryAmount
Sourcefn eq(&self, other: &MonetaryAmount) -> bool
fn eq(&self, other: &MonetaryAmount) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for MonetaryAmount
impl Serialize for MonetaryAmount
impl StructuralPartialEq for MonetaryAmount